DependencyInjection class

Dependency injection setup

Constructors

DependencyInjection()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

authenticateUseCase AuthenticateUseCase
Get authenticate use case
no setter
authRepository AuthRepository
Get auth repository
no setter
context BuildContext?
Get BuildContext for showing screens
no setter
deviceInfoDataSource DeviceInfoDataSource
Get device info data source
no setter
Get Navigator key
no setter

Static Methods

initialize(String baseUrl, {BuildContext? context, GlobalKey<NavigatorState>? navigatorKey}) Future<void>
Initialize dependencies with baseUrl and context
Navigate to a screen using the stored context
Navigate to a screen using MaterialPageRoute
showDialogWidget<T>({required WidgetBuilder builder, bool barrierDismissible = true, Color? barrierColor, String? barrierLabel, bool useSafeArea = true, bool useRootNavigator = false, RouteSettings? routeSettings}) Future<T?>?
Show a dialog using the stored context
showSnackBar(String message, {Duration duration = const Duration(seconds: 4), SnackBarAction? action, Color? backgroundColor}) → void
Show a snackbar using the stored context