MethodChannelHaloAuth class

An implementation of HaloAuthPlatform that uses method channels.

Inheritance

Constructors

MethodChannelHaloAuth()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceInfo() Future<Map<String, dynamic>>
Get device information from the native platform.
override
getMDMConfig() Future<Map<String, dynamic>?>
Get MDM configuration from iOS platform.
override
getPlatformVersion() Future<String?>
Get the platform version string.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportFeedback(String deviceId) Future<bool>
Report feedback to the native platform (Android only).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited