HaloAuthWeb class

A web implementation of the HaloAuthPlatform of the HaloAuth plugin.

Inheritance

Constructors

HaloAuthWeb()
Constructs a HaloAuthWeb

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceInfo() Future<Map<String, dynamic>>
Get device information from the native platform.
inherited
getMDMConfig() Future<Map<String, dynamic>?>
Get MDM configuration from iOS platform.
inherited
getPlatformVersion() Future<String?>
Returns a String containing the version of the platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportFeedback(String deviceId) Future<bool>
Report feedback to the native platform (Android only).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void