DeviceInfo class
Device information entity containing platform-specific device details.
Constructors
-
DeviceInfo({required String deviceId, required DeviceType deviceType, required PlatformType platformType, Map<
String, dynamic> ? mdmConfig}) -
const
Properties
- deviceId → String
-
Unique device identifier
final
- deviceType → DeviceType
-
Type of device (mobile or TV)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mdmConfig
→ Map<
String, dynamic> ? -
MDM configuration data (iOS only)
final
- platformType → PlatformType
-
Platform type (android, ios, windows, linux)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited